nvector._core.n_EA_E_and_n_EB_E2azimuth — nvector 0.7.5 documentation

# nvector._core.n_EA_E_and_n_EB_E2azimuth

`n_EA_E_and_n_EB_E2azimuth`(n_EA_E, n_EB_E, a=6378137, f=0.0033528106647474805, R_Ee=None)

  Returns azimuth from A to B, relative to North:

  Parameters
    n_EA_E, n_EB_E: 3 x n array

      n-vector(s) [no unit] of position A and B, respectively, decomposed in E.

    a: real scalar, default WGS-84 ellipsoid.

      Semi-major axis of the Earth ellipsoid given in [m].

    f: real scalar, default WGS-84 ellipsoid.

      Flattening [no unit] of the Earth ellipsoid. If f==0 then spherical Earth with radius a is used in stead of WGS-84.

    R_Ee3 x 3 array

      rotation matrix defining the axes of the coordinate frame E.

  Returns
    azimuth: n array

      Angle [rad] the line makes with a meridian, taken clockwise from north.